# Help!

A brief guide to make the most out of the Build Novel Project tool.

## Novel Title Formats

The format of the various title levels in the files under the Novel folder can be customised in these settings. The actual title given in the headings of your files will for instance replace all occurrences of the keyword %title%. Any static text will be left as-is in the final title. An empty field means the title isn't written out at all.

The available formatting keywords are:

%title% – This is replaced with the text you put in your headings in your documents

%chnum% – This is replaced with the chapter number of your chapter type headings. These are generated automaticall starting from 1, but ignoring chapter headings in files with "Unnumbered" layout.

%chnumword% – This is replaced with the chapter number, but instead of an arabic number, the word for it is used, e.g. One, Two, Fifteen, Twenty-Five, etc.

%scnum% – This is replaced with the scene number. The number is reset to one for each new chapter, so it is the scene number within the current chapter.

%scabsnum% – This is replaced with the absolute scene number. That is, the number is counted from the first scene in the novel, and not reset for each chapter.

\\ – Two backslashes are replaced by a line break.

Note: The Scene and Section formats are treated slightly differently than the other title formats. If the format is a constant text, that is, contains no %keyword% tags, it will be treated as a separator instead. Scene and Section separators are centred, and for scenes, not shown if placed directly after the chapter heading. For instance, it you want the classic three asterisk * * * separator between scenes, just put that into the scene format box, and nothing else.

## Build Overrides

Novel Outline Mode: This option will build an outline version of the novel rather than the full thing. It overrides the title format settings without changing them. Each title will be written out, and the synopsis text will appear instead of the body text of the files. Some of the other options are still available in Outline Mode.

## Include Non-Text Elements

Include Synopsis: This will add the synopsis comment as the first paragraph after each heading.

Include Comments: This will include any comments as additional paragraphs in the text.

Include Keywords: This will include any keywords and tags as clickable links after each heading.

## Additional Options

Include Novel Files: This means all files that don't have a layout of type "Note" will be included. This is the normal mode when exporting the novel itself without the notes.

Include Note Files: This means all files with a layout of type "Note" will be included. Titles in note files are always left as they appear.

Ignore Export Flag: Each file in the project tree has an "Include when building project" option set, which is indicated by a little check mark in the "Flags" column. Files without This tick will normally be skipped during build, but can be included if this option is enabled.